'''OpenGL extension ARB.fragment_program

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.fragment_program to provide a more 
Python-friendly API

Overview (from the spec)
	
	Unextended OpenGL mandates a certain set of configurable per-
	fragment computations defining texture application, texture 
	environment, color sum, and fog operations.  Several extensions have 
	added further per-fragment computations to OpenGL.  For example, 
	extensions have defined new texture environment capabilities 
	(ARB_texture_env_add, ARB_texture_env_combine, ARB_texture_env_dot3,
	ARB_texture_env_crossbar), per-fragment depth comparisons 
	(ARB_depth_texture, ARB_shadow, ARB_shadow_ambient, 
	EXT_shadow_funcs), per-fragment lighting (EXT_fragment_lighting, 
	EXT_light_texture), and environment mapped bump mapping 
	(ATI_envmap_bumpmap).  
	
	Each such extension adds a small set of relatively inflexible per-
	fragment computations.
	
	This inflexibility is in contrast to the typical flexibility 
	provided by the underlying programmable floating point engines 
	(whether micro-coded fragment engines, DSPs, or CPUs) that are 
	traditionally used to implement OpenGL's texturing computations.  
	The purpose of this extension is to expose to the OpenGL application 
	writer a significant degree of per-fragment programmability for 
	computing fragment parameters.
	
	For the purposes of discussing this extension, a fragment program is 
	a sequence of floating-point 4-component vector operations that 
	determines how a set of program parameters (not specific to an
	individual fragment) and an input set of per-fragment parameters are 
	transformed to a set of per-fragment result parameters.
	
	The per-fragment computations for standard OpenGL given a particular 
	set of texture and fog application modes (along with any state for 
	extensions defining per-fragment computations) is, in essence, a 
	fragment program.  However, the sequence of operations is defined 
	implicitly by the current OpenGL state settings rather than defined 
	explicitly as a sequence of instructions.
	
	This extension provides an explicit mechanism for defining fragment 
	program instruction sequences for application-defined fragment 
	programs.  In order to define such fragment programs, this extension 
	defines a fragment programming model including a floating-point
	4-component vector instruction set and a relatively large set of 
	floating-point 4-component registers.
	
	The extension's fragment programming model is designed for efficient
	hardware implementation and to support a wide variety of fragment 
	programs.  By design, the entire set of existing fragment programs 
	defined by existing OpenGL per-fragment computation extensions can 
	be implemented using the extension's fragment programming model.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/fragment_program.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.fragment_program import *
from OpenGL.raw.GL.ARB.fragment_program import _EXTENSION_NAME

def glInitFragmentProgramARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glProgramStringARB.string size not checked against len
glProgramStringARB=wrapper.wrapper(glProgramStringARB).setInputArraySize(
    'string', None
)
# INPUT glDeleteProgramsARB.programs size not checked against n
glDeleteProgramsARB=wrapper.wrapper(glDeleteProgramsARB).setInputArraySize(
    'programs', None
)
glGenProgramsARB=wrapper.wrapper(glGenProgramsARB).setOutput(
    'programs',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glProgramEnvParameter4dvARB=wrapper.wrapper(glProgramEnvParameter4dvARB).setInputArraySize(
    'params', 4
)
glProgramEnvParameter4fvARB=wrapper.wrapper(glProgramEnvParameter4fvARB).setInputArraySize(
    'params', 4
)
glProgramLocalParameter4dvARB=wrapper.wrapper(glProgramLocalParameter4dvARB).setInputArraySize(
    'params', 4
)
glProgramLocalParameter4fvARB=wrapper.wrapper(glProgramLocalParameter4fvARB).setInputArraySize(
    'params', 4
)
glGetProgramEnvParameterdvARB=wrapper.wrapper(glGetProgramEnvParameterdvARB).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetProgramEnvParameterfvARB=wrapper.wrapper(glGetProgramEnvParameterfvARB).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetProgramLocalParameterdvARB=wrapper.wrapper(glGetProgramLocalParameterdvARB).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetProgramLocalParameterfvARB=wrapper.wrapper(glGetProgramLocalParameterfvARB).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetProgramivARB=wrapper.wrapper(glGetProgramivARB).setOutput(
    'params',size=(1,),orPassIn=True
)
# OUTPUT glGetProgramStringARB.string COMPSIZE(target, pname) 
### END AUTOGENERATED SECTION



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_EXT_platform_base'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_EXT_platform_base',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,ctypes.c_void_p,arrays.GLintArray)
def eglCreatePlatformPixmapSurfaceEXT(dpy,config,native_pixmap,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,ctypes.c_void_p,arrays.GLintArray)
def eglCreatePlatformWindowSurfaceEXT(dpy,config,native_window,attrib_list):pass
@_f
@_p.types(_cs.EGLDisplay,_cs.EGLenum,ctypes.c_void_p,arrays.GLintArray)
def eglGetPlatformDisplayEXT(platform,native_display,attrib_list):pass



'''OpenGL extension WIN.phong_shading

This module customises the behaviour of the 
OpenGL.raw.GL.WIN.phong_shading to provide a more 
Python-friendly API

Overview (from the spec)
	
	WIN_phong_shading enables rendering Phong shaded primitives using OpenGL.
	Phong shading is a well known shading technique documented 
	in most graphics texts. 
	
	As opposed to Gouraud (or smooth) shading, which simply calculates the 
	normals at the vertices and then interpolates the colors of the pixels, 
	Phong shading involves interpolating an individual normal for every pixel,
	and then applying the shading model to each pixel based on its normal 
	component. 
	
	While Phong shading requires substantially more computation than does 
	Gouraud shading, the resulting images are more realistic, especially if the
	primitives are large. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/WIN/phong_shading.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.WIN.phong_shading import *
from OpenGL.raw.GL.WIN.phong_shading import _EXTENSION_NAME

def glInitPhongShadingWIN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_ARB_render_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_ARB_render_texture',error_checker=_errors._error_checker)
WGL_AUX0_ARB=_C('WGL_AUX0_ARB',0x2087)
WGL_AUX1_ARB=_C('WGL_AUX1_ARB',0x2088)
WGL_AUX2_ARB=_C('WGL_AUX2_ARB',0x2089)
WGL_AUX3_ARB=_C('WGL_AUX3_ARB',0x208A)
WGL_AUX4_ARB=_C('WGL_AUX4_ARB',0x208B)
WGL_AUX5_ARB=_C('WGL_AUX5_ARB',0x208C)
WGL_AUX6_ARB=_C('WGL_AUX6_ARB',0x208D)
WGL_AUX7_ARB=_C('WGL_AUX7_ARB',0x208E)
WGL_AUX8_ARB=_C('WGL_AUX8_ARB',0x208F)
WGL_AUX9_ARB=_C('WGL_AUX9_ARB',0x2090)
WGL_BACK_LEFT_ARB=_C('WGL_BACK_LEFT_ARB',0x2085)
WGL_BACK_RIGHT_ARB=_C('WGL_BACK_RIGHT_ARB',0x2086)
WGL_BIND_TO_TEXTURE_RGBA_ARB=_C('WGL_BIND_TO_TEXTURE_RGBA_ARB',0x2071)
WGL_BIND_TO_TEXTURE_RGB_ARB=_C('WGL_BIND_TO_TEXTURE_RGB_ARB',0x2070)
WGL_CUBE_MAP_FACE_ARB=_C('WGL_CUBE_MAP_FACE_ARB',0x207C)
WGL_FRONT_LEFT_ARB=_C('WGL_FRONT_LEFT_ARB',0x2083)
WGL_FRONT_RIGHT_ARB=_C('WGL_FRONT_RIGHT_ARB',0x2084)
WGL_MIPMAP_LEVEL_ARB=_C('WGL_MIPMAP_LEVEL_ARB',0x207B)
WGL_MIPMAP_TEXTURE_ARB=_C('WGL_MIPMAP_TEXTURE_ARB',0x2074)
WGL_NO_TEXTURE_ARB=_C('WGL_NO_TEXTURE_ARB',0x2077)
WGL_TEXTURE_1D_ARB=_C('WGL_TEXTURE_1D_ARB',0x2079)
WGL_TEXTURE_2D_ARB=_C('WGL_TEXTURE_2D_ARB',0x207A)
WGL_TEXTURE_CUBE_MAP_ARB=_C('WGL_TEXTURE_CUBE_MAP_ARB',0x2078)
WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB=_C('WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB',0x207E)
WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB=_C('WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB',0x2080)
WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB=_C('WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB',0x2082)
WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB=_C('WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB',0x207D)
WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB=_C('WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB',0x207F)
WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB=_C('WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB',0x2081)
WGL_TEXTURE_FORMAT_ARB=_C('WGL_TEXTURE_FORMAT_ARB',0x2072)
WGL_TEXTURE_RGBA_ARB=_C('WGL_TEXTURE_RGBA_ARB',0x2076)
WGL_TEXTURE_RGB_ARB=_C('WGL_TEXTURE_RGB_ARB',0x2075)
WGL_TEXTURE_TARGET_ARB=_C('WGL_TEXTURE_TARGET_ARB',0x2073)
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,_cs.c_int)
def wglBindTexImageARB(hPbuffer,iBuffer):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,_cs.c_int)
def wglReleaseTexImageARB(hPbuffer,iBuffer):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,ctypes.POINTER(_cs.c_int))
def wglSetPbufferAttribARB(hPbuffer,piAttribList):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_KHR_texture_compression_astc_ldr'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_KHR_texture_compression_astc_ldr',error_checker=_errors._error_checker)
GL_COMPRESSED_RGBA_ASTC_10x10_KHR=_C('GL_COMPRESSED_RGBA_ASTC_10x10_KHR',0x93BB)
GL_COMPRESSED_RGBA_ASTC_10x5_KHR=_C('GL_COMPRESSED_RGBA_ASTC_10x5_KHR',0x93B8)
GL_COMPRESSED_RGBA_ASTC_10x6_KHR=_C('GL_COMPRESSED_RGBA_ASTC_10x6_KHR',0x93B9)
GL_COMPRESSED_RGBA_ASTC_10x8_KHR=_C('GL_COMPRESSED_RGBA_ASTC_10x8_KHR',0x93BA)
GL_COMPRESSED_RGBA_ASTC_12x10_KHR=_C('GL_COMPRESSED_RGBA_ASTC_12x10_KHR',0x93BC)
GL_COMPRESSED_RGBA_ASTC_12x12_KHR=_C('GL_COMPRESSED_RGBA_ASTC_12x12_KHR',0x93BD)
GL_COMPRESSED_RGBA_ASTC_4x4_KHR=_C('GL_COMPRESSED_RGBA_ASTC_4x4_KHR',0x93B0)
GL_COMPRESSED_RGBA_ASTC_5x4_KHR=_C('GL_COMPRESSED_RGBA_ASTC_5x4_KHR',0x93B1)
GL_COMPRESSED_RGBA_ASTC_5x5_KHR=_C('GL_COMPRESSED_RGBA_ASTC_5x5_KHR',0x93B2)
GL_COMPRESSED_RGBA_ASTC_6x5_KHR=_C('GL_COMPRESSED_RGBA_ASTC_6x5_KHR',0x93B3)
GL_COMPRESSED_RGBA_ASTC_6x6_KHR=_C('GL_COMPRESSED_RGBA_ASTC_6x6_KHR',0x93B4)
GL_COMPRESSED_RGBA_ASTC_8x5_KHR=_C('GL_COMPRESSED_RGBA_ASTC_8x5_KHR',0x93B5)
GL_COMPRESSED_RGBA_ASTC_8x6_KHR=_C('GL_COMPRESSED_RGBA_ASTC_8x6_KHR',0x93B6)
GL_COMPRESSED_RGBA_ASTC_8x8_KHR=_C('GL_COMPRESSED_RGBA_ASTC_8x8_KHR',0x93B7)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR',0x93DB)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR',0x93D8)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR',0x93D9)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR',0x93DA)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR',0x93DC)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR',0x93DD)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR',0x93D0)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR',0x93D1)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR',0x93D2)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR',0x93D3)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR',0x93D4)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR',0x93D5)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR',0x93D6)
GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR=_C('GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR',0x93D7)




'''OpenGL extension EXT.secondary_color

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.secondary_color to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying the RGB components of the secondary
	color used in the Color Sum stage, instead of using the default
	(0,0,0,0) color. It applies only in RGBA mode and when LIGHTING is
	disabled.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/secondary_color.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.secondary_color import *
from OpenGL.raw.GL.EXT.secondary_color import _EXTENSION_NAME

def glInitSecondaryColorEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glSecondaryColor3bvEXT=wrapper.wrapper(glSecondaryColor3bvEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3dvEXT=wrapper.wrapper(glSecondaryColor3dvEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3fvEXT=wrapper.wrapper(glSecondaryColor3fvEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3ivEXT=wrapper.wrapper(glSecondaryColor3ivEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3svEXT=wrapper.wrapper(glSecondaryColor3svEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3ubvEXT=wrapper.wrapper(glSecondaryColor3ubvEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3uivEXT=wrapper.wrapper(glSecondaryColor3uivEXT).setInputArraySize(
    'v', 3
)
glSecondaryColor3usvEXT=wrapper.wrapper(glSecondaryColor3usvEXT).setInputArraySize(
    'v', 3
)
# INPUT glSecondaryColorPointerEXT.pointer size not checked against 'size,type,stride'
glSecondaryColorPointerEXT=wrapper.wrapper(glSecondaryColorPointerEXT).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.pixel_data_range

This module customises the behaviour of the 
OpenGL.raw.GL.NV.pixel_data_range to provide a more 
Python-friendly API

Overview (from the spec)
	
	The vertex array range extension is intended to improve the
	efficiency of OpenGL vertex arrays.  OpenGL vertex arrays' coherency
	model and ability to access memory from arbitrary locations in memory
	prevented implementations from using DMA (Direct Memory Access)
	operations.
	
	Many image-intensive applications, such as those that use dynamically
	generated textures, face similar problems.  These applications would
	like to be able to sustain throughputs of hundreds of millions of
	pixels per second through DrawPixels and hundreds of millions of
	texels per second through TexSubImage.
	
	However, the same restrictions that limited vertex throughput also
	limit pixel throughput.
	
	By the time that any pixel operation that reads data from user memory
	returns, OpenGL requires that it must be safe for the application to
	start using that memory for a different purpose.  This coherency
	model prevents asynchronous DMA transfers directly out of the user's
	buffer.
	
	There are also no restrictions on the pointer provided to pixel
	operations or on the size of the data.  To facilitate DMA
	implementations, the driver needs to know in advance what region of
	the address space to lock down.
	
	Vertex arrays faced both of these restrictions already, but pixel
	operations have one additional complicating factor -- they are
	bidirectional.  Vertex array data is always being transfered from the
	application to the driver and the HW, whereas pixel operations
	sometimes transfer data to the application from the driver and HW.
	Note that the types of memory that are suitable for DMA for reading
	and writing purposes are often different.  For example, on many PC
	platforms, DMA pulling is best accomplished with write-combined
	(uncached) AGP memory, while pushing data should use cached memory so
	that the application can read the data efficiently once it has been
	read back over the AGP bus.
	
	This extension defines an API where an application can specify two
	pixel data ranges, which are analogous to vertex array ranges, except
	that one is for operations where the application is reading data
	(e.g. glReadPixels) and one is for operations where the application
	is writing data (e.g. glDrawPixels, glTexSubImage2D, etc.).  Each
	pixel data range has a pointer to its start and a length in bytes.
	
	When the pixel data range is enabled, and if the pointer specified
	as the argument to a pixel operation is inside the corresponding
	pixel data range, the implementation may choose to asynchronously
	pull data from the pixel data range or push data to the pixel data
	range.  Data pulled from outside the pixel data range is undefined,
	while pushing data to outside the pixel data range produces undefined
	results.
	
	The application may synchronize with the hardware in one of two ways:
	by flushing the pixel data range (or causing an implicit flush) or by
	using the NV_fence extension to insert fences in the command stream.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/pixel_data_range.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.pixel_data_range import *
from OpenGL.raw.GL.NV.pixel_data_range import _EXTENSION_NAME

def glInitPixelDataRangeNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPixelDataRangeNV.pointer size not checked against length
glPixelDataRangeNV=wrapper.wrapper(glPixelDataRangeNV).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_import_context'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_import_context',error_checker=_errors._error_checker)
GLX_SCREEN_EXT=_C('GLX_SCREEN_EXT',0x800C)
GLX_SHARE_CONTEXT_EXT=_C('GLX_SHARE_CONTEXT_EXT',0x800A)
GLX_VISUAL_ID_EXT=_C('GLX_VISUAL_ID_EXT',0x800B)
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXContext)
def glXFreeContextEXT(dpy,context):pass
@_f
@_p.types(_cs.GLXContextID,_cs.GLXContext)
def glXGetContextIDEXT(context):pass
@_f
@_p.types(ctypes.POINTER(_cs.Display),)
def glXGetCurrentDisplayEXT():pass
@_f
@_p.types(_cs.GLXContext,ctypes.POINTER(_cs.Display),_cs.GLXContextID)
def glXImportContextEXT(dpy,contextID):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXContext,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXQueryContextInfoEXT(dpy,context,attribute,value):pass



'''OpenGL extension KHR.texture_compression_astc_hdr

This module customises the behaviour of the 
OpenGL.raw.GL.KHR.texture_compression_astc_hdr to provide a more 
Python-friendly API

Overview (from the spec)
	
	Adaptive Scalable Texture Compression (ASTC) is a new texture
	compression technology that offers unprecendented flexibility,
	while producing better or comparable results than existing texture
	compressions at all bit rates. It includes support for 2D and
	slice-based 3D textures, with low and high dynamic range, at
	bitrates from below 1 bit/pixel up to 8 bits/pixel in fine steps.
	
	The goal of this extension is to support the full 2D profile of the
	ASTC texture compression specification, and allow construction of
	3D textures from multiple 2D slices.
	
	ASTC-compressed textures are handled in OpenGL ES and OpenGL by
	adding new supported formats to the existing mechanisms for handling
	compressed textures.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/texture_compression_astc_hdr.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.KHR.texture_compression_astc_hdr import *
from OpenGL.raw.GL.KHR.texture_compression_astc_hdr import _EXTENSION_NAME

def glInitTextureCompressionAstcHdrKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension GREMEDY.string_marker

This module customises the behaviour of the 
OpenGL.raw.GL.GREMEDY.string_marker to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism to insert textual markers into
	the OpenGL stream. 
	
	When debugging or profiling an OpenGL application some of the most
	important tools are stream loggers, which just output a list of the
	called OpenGL commands, and profilers, which show at which points
	the pipeline is bottlenecked for a given part of the frame. The
	problem in using these is that there is a definite loss of
	information between the application and the used debugger/profiler.
	The application generally has a pretty good idea what is rendered
	when (e.g. rendering background, landscape, building, players,
	particle effects, bullets etc.), but the debugger/profiler only
	sees the OpenGL stream. To analyze the stream developers have to
	guess what is done when by following the program code and the log
	output in parallel, which can get difficult for systems that
	restructure their internal pipeline or do lazy changes.
	
	This extension is really only useful for these debuggers and
	profilers, and not for actual drivers. In fact, it is not expected
	that any standard driver would ever implement this extension. The
	main point of having this extension is to allow applications to have a
	clean way of accessing this functionality only when they are run
	under the control of a debugger/profiler, without having to
	recompile or change the application source code.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/GREMEDY/string_marker.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.GREMEDY.string_marker import *
from OpenGL.raw.GL.GREMEDY.string_marker import _EXTENSION_NAME

def glInitStringMarkerGREMEDY():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glStringMarkerGREMEDY.string size not checked against len
glStringMarkerGREMEDY=wrapper.wrapper(glStringMarkerGREMEDY).setInputArraySize(
    'string', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.vertex_array_object

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.vertex_array_object to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/vertex_array_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.vertex_array_object import *
from OpenGL.raw.GLES2.OES.vertex_array_object import _EXTENSION_NAME

def glInitVertexArrayObjectOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeleteVertexArraysOES.arrays size not checked against n
glDeleteVertexArraysOES=wrapper.wrapper(glDeleteVertexArraysOES).setInputArraySize(
    'arrays', None
)
# INPUT glGenVertexArraysOES.arrays size not checked against n
glGenVertexArraysOES=wrapper.wrapper(glGenVertexArraysOES).setInputArraySize(
    'arrays', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.separate_shader_objects

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.separate_shader_objects to provide a more 
Python-friendly API

Overview (from the spec)
	
	Conventional GLSL requires multiple shader stages (vertex,
	fragment, geometry, tessellation control, and tessellation
	evaluation) to be linked into a single monolithic program object to
	specify a GLSL shader for each stage.
	
	While GLSL's monolithic approach has some advantages for
	optimizing shaders as a unit that span multiple stages, all
	existing GPU hardware supports the more flexible mix-and-match
	approach.
	
	Shaders written for HLSL9, Cg, the prior OpenGL assembly program
	extensions, and game console favor a more flexible "mix-and-match"
	approach to specifying shaders independently for these different
	shader stages.  Many developers build their shader content around
	the mix-and-match approach where they can use a single vertex shader
	with multiple fragment shaders (or vice versa).
	
	This extension adopts a "mix-and-match" shader stage model for GLSL
	allowing multiple different GLSL program objects to be bound at once
	each to an individual rendering pipeline stage independently of
	other stage bindings. This allows program objects to contain only
	the shader stages that best suit the applications needs.
	
	This extension introduces the program pipeline object that serves as
	a container for the program bound to any particular rendering stage.
	It can be bound, unbound, and rebound to simply save and restore the
	complete shader stage to program object bindings.  Like framebuffer
	and vertex array objects, program pipeline objects are "container"
	objects that are not shared between contexts.
	
	To bind a program object to a specific shader stage or set of
	stages, UseProgramStages is used.  The VERTEX_SHADER_BIT,
	GEOMETRY_SHADER_BIT, FRAGMENT_SHADER_BIT, TESS_CONTROL_SHADER_BIT,
	and TESS_EVALUATION_SHADER_BIT tokens refer to the conventional
	vertex, geometry, fragment, tessellation control and tessellation
	evaluation stages respectively. ActiveShaderProgram specifies the
	program that Uniform* commands will update.
	
	While ActiveShaderProgram allows the use of conventional Uniform*
	commands to update uniform variable values for separable program
	objects, this extension provides a preferrable interface in a set
	of ProgramUniform* commands that update the same uniform variables
	but take a parameter indicating the program object to be updated,
	rather than updating the currently active program object. These
	commands mirror those introduced in EXT_direct_state_access.
	
	While glActiveShaderProgram provides a selector for setting and
	querying uniform values of a program object, the glProgramUniform*
	commands provide a selector-free way to modify uniforms of a GLSL
	program object without an explicit bind. This selector-free model
	reduces API overhead and provides a cleaner interface for
	applications.
	
	Separate linking creates the possibility that certain output varyings
	of a shader may go unread by the subsequent shader inputting varyings.
	In this case, the output varyings are simply ignored.  It is also
	possible input varyings from a shader may not be written as output
	varyings of a preceding shader.  In this case, the unwritten input
	varying values are undefined.
	
	This extension builds on the proof-of-concept provided by
	EXT_separate_shader_objects which demonstrated that separate
	shader objects can work for GLSL.  EXT_separate_shader_objects
	was a response to repeated requests for this functionality from
	3D developers.
	
	This ARB version addresses several "loose ends" in the prior
	EXT extension.  In particular, it allows user-defined varyings
	with explicitly defined locations or implicitly assigned locations.
	
	This ARB extension extends the GLSL language's use of layout
	qualifiers to provide cross-stage interfacing.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/separate_shader_objects.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.separate_shader_objects import *
from OpenGL.raw.GL.ARB.separate_shader_objects import _EXTENSION_NAME

def glInitSeparateShaderObjectsARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glCreateShaderProgramv.strings size not checked against count
glCreateShaderProgramv=wrapper.wrapper(glCreateShaderProgramv).setInputArraySize(
    'strings', None
)
# INPUT glDeleteProgramPipelines.pipelines size not checked against n
glDeleteProgramPipelines=wrapper.wrapper(glDeleteProgramPipelines).setInputArraySize(
    'pipelines', None
)
glGenProgramPipelines=wrapper.wrapper(glGenProgramPipelines).setOutput(
    'pipelines',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetProgramPipelineiv=wrapper.wrapper(glGetProgramPipelineiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glProgramUniform1iv=wrapper.wrapper(glProgramUniform1iv).setInputArraySize(
    'value', 1
)
glProgramUniform1fv=wrapper.wrapper(glProgramUniform1fv).setInputArraySize(
    'value', 1
)
glProgramUniform1dv=wrapper.wrapper(glProgramUniform1dv).setInputArraySize(
    'value', 1
)
glProgramUniform1uiv=wrapper.wrapper(glProgramUniform1uiv).setInputArraySize(
    'value', 1
)
glProgramUniform2iv=wrapper.wrapper(glProgramUniform2iv).setInputArraySize(
    'value', 2
)
glProgramUniform2fv=wrapper.wrapper(glProgramUniform2fv).setInputArraySize(
    'value', 2
)
glProgramUniform2dv=wrapper.wrapper(glProgramUniform2dv).setInputArraySize(
    'value', 2
)
glProgramUniform2uiv=wrapper.wrapper(glProgramUniform2uiv).setInputArraySize(
    'value', 2
)
glProgramUniform3iv=wrapper.wrapper(glProgramUniform3iv).setInputArraySize(
    'value', 3
)
glProgramUniform3fv=wrapper.wrapper(glProgramUniform3fv).setInputArraySize(
    'value', 3
)
glProgramUniform3dv=wrapper.wrapper(glProgramUniform3dv).setInputArraySize(
    'value', 3
)
glProgramUniform3uiv=wrapper.wrapper(glProgramUniform3uiv).setInputArraySize(
    'value', 3
)
glProgramUniform4iv=wrapper.wrapper(glProgramUniform4iv).setInputArraySize(
    'value', 4
)
glProgramUniform4fv=wrapper.wrapper(glProgramUniform4fv).setInputArraySize(
    'value', 4
)
glProgramUniform4dv=wrapper.wrapper(glProgramUniform4dv).setInputArraySize(
    'value', 4
)
glProgramUniform4uiv=wrapper.wrapper(glProgramUniform4uiv).setInputArraySize(
    'value', 4
)
glProgramUniformMatrix2fv=wrapper.wrapper(glProgramUniformMatrix2fv).setInputArraySize(
    'value', 2
)
glProgramUniformMatrix3fv=wrapper.wrapper(glProgramUniformMatrix3fv).setInputArraySize(
    'value', 3
)
glProgramUniformMatrix4fv=wrapper.wrapper(glProgramUniformMatrix4fv).setInputArraySize(
    'value', 4
)
glProgramUniformMatrix2dv=wrapper.wrapper(glProgramUniformMatrix2dv).setInputArraySize(
    'value', 2
)
glProgramUniformMatrix3dv=wrapper.wrapper(glProgramUniformMatrix3dv).setInputArraySize(
    'value', 3
)
glProgramUniformMatrix4dv=wrapper.wrapper(glProgramUniformMatrix4dv).setInputArraySize(
    'value', 4
)
# INPUT glProgramUniformMatrix2x3fv.value size not checked against count
glProgramUniformMatrix2x3fv=wrapper.wrapper(glProgramUniformMatrix2x3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x2fv.value size not checked against count
glProgramUniformMatrix3x2fv=wrapper.wrapper(glProgramUniformMatrix3x2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x4fv.value size not checked against count
glProgramUniformMatrix2x4fv=wrapper.wrapper(glProgramUniformMatrix2x4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x2fv.value size not checked against count
glProgramUniformMatrix4x2fv=wrapper.wrapper(glProgramUniformMatrix4x2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x4fv.value size not checked against count
glProgramUniformMatrix3x4fv=wrapper.wrapper(glProgramUniformMatrix3x4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x3fv.value size not checked against count
glProgramUniformMatrix4x3fv=wrapper.wrapper(glProgramUniformMatrix4x3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x3dv.value size not checked against count
glProgramUniformMatrix2x3dv=wrapper.wrapper(glProgramUniformMatrix2x3dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x2dv.value size not checked against count
glProgramUniformMatrix3x2dv=wrapper.wrapper(glProgramUniformMatrix3x2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x4dv.value size not checked against count
glProgramUniformMatrix2x4dv=wrapper.wrapper(glProgramUniformMatrix2x4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x2dv.value size not checked against count
glProgramUniformMatrix4x2dv=wrapper.wrapper(glProgramUniformMatrix4x2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x4dv.value size not checked against count
glProgramUniformMatrix3x4dv=wrapper.wrapper(glProgramUniformMatrix3x4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x3dv.value size not checked against count
glProgramUniformMatrix4x3dv=wrapper.wrapper(glProgramUniformMatrix4x3dv).setInputArraySize(
    'value', None
)
glGetProgramPipelineInfoLog=wrapper.wrapper(glGetProgramPipelineInfoLog).setOutput(
    'infoLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_register_combiners'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_register_combiners',error_checker=_errors._error_checker)
GL_BIAS_BY_NEGATIVE_ONE_HALF_NV=_C('GL_BIAS_BY_NEGATIVE_ONE_HALF_NV',0x8541)
GL_COLOR_SUM_CLAMP_NV=_C('GL_COLOR_SUM_CLAMP_NV',0x854F)
GL_COMBINER0_NV=_C('GL_COMBINER0_NV',0x8550)
GL_COMBINER1_NV=_C('GL_COMBINER1_NV',0x8551)
GL_COMBINER2_NV=_C('GL_COMBINER2_NV',0x8552)
GL_COMBINER3_NV=_C('GL_COMBINER3_NV',0x8553)
GL_COMBINER4_NV=_C('GL_COMBINER4_NV',0x8554)
GL_COMBINER5_NV=_C('GL_COMBINER5_NV',0x8555)
GL_COMBINER6_NV=_C('GL_COMBINER6_NV',0x8556)
GL_COMBINER7_NV=_C('GL_COMBINER7_NV',0x8557)
GL_COMBINER_AB_DOT_PRODUCT_NV=_C('GL_COMBINER_AB_DOT_PRODUCT_NV',0x8545)
GL_COMBINER_AB_OUTPUT_NV=_C('GL_COMBINER_AB_OUTPUT_NV',0x854A)
GL_COMBINER_BIAS_NV=_C('GL_COMBINER_BIAS_NV',0x8549)
GL_COMBINER_CD_DOT_PRODUCT_NV=_C('GL_COMBINER_CD_DOT_PRODUCT_NV',0x8546)
GL_COMBINER_CD_OUTPUT_NV=_C('GL_COMBINER_CD_OUTPUT_NV',0x854B)
GL_COMBINER_COMPONENT_USAGE_NV=_C('GL_COMBINER_COMPONENT_USAGE_NV',0x8544)
GL_COMBINER_INPUT_NV=_C('GL_COMBINER_INPUT_NV',0x8542)
GL_COMBINER_MAPPING_NV=_C('GL_COMBINER_MAPPING_NV',0x8543)
GL_COMBINER_MUX_SUM_NV=_C('GL_COMBINER_MUX_SUM_NV',0x8547)
GL_COMBINER_SCALE_NV=_C('GL_COMBINER_SCALE_NV',0x8548)
GL_COMBINER_SUM_OUTPUT_NV=_C('GL_COMBINER_SUM_OUTPUT_NV',0x854C)
GL_CONSTANT_COLOR0_NV=_C('GL_CONSTANT_COLOR0_NV',0x852A)
GL_CONSTANT_COLOR1_NV=_C('GL_CONSTANT_COLOR1_NV',0x852B)
GL_DISCARD_NV=_C('GL_DISCARD_NV',0x8530)
GL_EXPAND_NEGATE_NV=_C('GL_EXPAND_NEGATE_NV',0x8539)
GL_EXPAND_NORMAL_NV=_C('GL_EXPAND_NORMAL_NV',0x8538)
GL_E_TIMES_F_NV=_C('GL_E_TIMES_F_NV',0x8531)
GL_FOG=_C('GL_FOG',0x0B60)
GL_HALF_BIAS_NEGATE_NV=_C('GL_HALF_BIAS_NEGATE_NV',0x853B)
GL_HALF_BIAS_NORMAL_NV=_C('GL_HALF_BIAS_NORMAL_NV',0x853A)
GL_MAX_GENERAL_COMBINERS_NV=_C('GL_MAX_GENERAL_COMBINERS_NV',0x854D)
GL_NONE=_C('GL_NONE',0)
GL_NUM_GENERAL_COMBINERS_NV=_C('GL_NUM_GENERAL_COMBINERS_NV',0x854E)
GL_PRIMARY_COLOR_NV=_C('GL_PRIMARY_COLOR_NV',0x852C)
GL_REGISTER_COMBINERS_NV=_C('GL_REGISTER_COMBINERS_NV',0x8522)
GL_SCALE_BY_FOUR_NV=_C('GL_SCALE_BY_FOUR_NV',0x853F)
GL_SCALE_BY_ONE_HALF_NV=_C('GL_SCALE_BY_ONE_HALF_NV',0x8540)
GL_SCALE_BY_TWO_NV=_C('GL_SCALE_BY_TWO_NV',0x853E)
GL_SECONDARY_COLOR_NV=_C('GL_SECONDARY_COLOR_NV',0x852D)
GL_SIGNED_IDENTITY_NV=_C('GL_SIGNED_IDENTITY_NV',0x853C)
GL_SIGNED_NEGATE_NV=_C('GL_SIGNED_NEGATE_NV',0x853D)
GL_SPARE0_NV=_C('GL_SPARE0_NV',0x852E)
GL_SPARE0_PLUS_SECONDARY_COLOR_NV=_C('GL_SPARE0_PLUS_SECONDARY_COLOR_NV',0x8532)
GL_SPARE1_NV=_C('GL_SPARE1_NV',0x852F)
GL_TEXTURE0_ARB=_C('GL_TEXTURE0_ARB',0x84C0)
GL_TEXTURE1_ARB=_C('GL_TEXTURE1_ARB',0x84C1)
GL_UNSIGNED_IDENTITY_NV=_C('GL_UNSIGNED_IDENTITY_NV',0x8536)
GL_UNSIGNED_INVERT_NV=_C('GL_UNSIGNED_INVERT_NV',0x8537)
GL_VARIABLE_A_NV=_C('GL_VARIABLE_A_NV',0x8523)
GL_VARIABLE_B_NV=_C('GL_VARIABLE_B_NV',0x8524)
GL_VARIABLE_C_NV=_C('GL_VARIABLE_C_NV',0x8525)
GL_VARIABLE_D_NV=_C('GL_VARIABLE_D_NV',0x8526)
GL_VARIABLE_E_NV=_C('GL_VARIABLE_E_NV',0x8527)
GL_VARIABLE_F_NV=_C('GL_VARIABLE_F_NV',0x8528)
GL_VARIABLE_G_NV=_C('GL_VARIABLE_G_NV',0x8529)
GL_ZERO=_C('GL_ZERO',0)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glCombinerInputNV(stage,portion,variable,input,mapping,componentUsage):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean)
def glCombinerOutputNV(stage,portion,abOutput,cdOutput,sumOutput,scale,bias,abDotProduct,cdDotProduct,muxSum):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glCombinerParameterfNV(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glCombinerParameterfvNV(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glCombinerParameteriNV(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glCombinerParameterivNV(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glFinalCombinerInputNV(variable,input,mapping,componentUsage):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetCombinerInputParameterfvNV(stage,portion,variable,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetCombinerInputParameterivNV(stage,portion,variable,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetCombinerOutputParameterfvNV(stage,portion,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetCombinerOutputParameterivNV(stage,portion,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetFinalCombinerInputParameterfvNV(variable,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFinalCombinerInputParameterivNV(variable,pname,params):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_separate_stencil'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_separate_stencil',error_checker=_errors._error_checker)
GL_STENCIL_BACK_FAIL_ATI=_C('GL_STENCIL_BACK_FAIL_ATI',0x8801)
GL_STENCIL_BACK_FUNC_ATI=_C('GL_STENCIL_BACK_FUNC_ATI',0x8800)
GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI=_C('GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI',0x8802)
GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI=_C('GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI',0x8803)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLuint)
def glStencilFuncSeparateATI(frontfunc,backfunc,ref,mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glStencilOpSeparateATI(face,sfail,dpfail,dppass):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_transpose_matrix'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_transpose_matrix',error_checker=_errors._error_checker)
GL_TRANSPOSE_COLOR_MATRIX_ARB=_C('GL_TRANSPOSE_COLOR_MATRIX_ARB',0x84E6)
GL_TRANSPOSE_MODELVIEW_MATRIX_ARB=_C('GL_TRANSPOSE_MODELVIEW_MATRIX_ARB',0x84E3)
GL_TRANSPOSE_PROJECTION_MATRIX_ARB=_C('GL_TRANSPOSE_PROJECTION_MATRIX_ARB',0x84E4)
GL_TRANSPOSE_TEXTURE_MATRIX_ARB=_C('GL_TRANSPOSE_TEXTURE_MATRIX_ARB',0x84E5)
@_f
@_p.types(None,arrays.GLdoubleArray)
def glLoadTransposeMatrixdARB(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glLoadTransposeMatrixfARB(m):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glMultTransposeMatrixdARB(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glMultTransposeMatrixfARB(m):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_fragment_program'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_fragment_program',error_checker=_errors._error_checker)
GL_FRAGMENT_PROGRAM_BINDING_NV=_C('GL_FRAGMENT_PROGRAM_BINDING_NV',0x8873)
GL_FRAGMENT_PROGRAM_NV=_C('GL_FRAGMENT_PROGRAM_NV',0x8870)
GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV=_C('GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV',0x8868)
GL_MAX_TEXTURE_COORDS_NV=_C('GL_MAX_TEXTURE_COORDS_NV',0x8871)
GL_MAX_TEXTURE_IMAGE_UNITS_NV=_C('GL_MAX_TEXTURE_IMAGE_UNITS_NV',0x8872)
GL_PROGRAM_ERROR_STRING_NV=_C('GL_PROGRAM_ERROR_STRING_NV',0x8874)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,arrays.GLdoubleArray)
def glGetProgramNamedParameterdvNV(id,len,name,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,arrays.GLfloatArray)
def glGetProgramNamedParameterfvNV(id,len,name,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glProgramNamedParameter4dNV(id,len,name,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,arrays.GLdoubleArray)
def glProgramNamedParameter4dvNV(id,len,name,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramNamedParameter4fNV(id,len,name,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray,arrays.GLfloatArray)
def glProgramNamedParameter4fvNV(id,len,name,v):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_buffer_storage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_buffer_storage',error_checker=_errors._error_checker)
GL_BUFFER_IMMUTABLE_STORAGE=_C('GL_BUFFER_IMMUTABLE_STORAGE',0x821F)
GL_BUFFER_STORAGE_FLAGS=_C('GL_BUFFER_STORAGE_FLAGS',0x8220)
GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT=_C('GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT',0x00004000)
GL_CLIENT_STORAGE_BIT=_C('GL_CLIENT_STORAGE_BIT',0x0200)
GL_DYNAMIC_STORAGE_BIT=_C('GL_DYNAMIC_STORAGE_BIT',0x0100)
GL_MAP_COHERENT_BIT=_C('GL_MAP_COHERENT_BIT',0x0080)
GL_MAP_PERSISTENT_BIT=_C('GL_MAP_PERSISTENT_BIT',0x0040)
GL_MAP_READ_BIT=_C('GL_MAP_READ_BIT',0x0001)
GL_MAP_WRITE_BIT=_C('GL_MAP_WRITE_BIT',0x0002)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizeiptr,ctypes.c_void_p,_cs.GLbitfield)
def glBufferStorage(target,size,data,flags):pass



'''OpenGL extension EXT.copy_texture

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.copy_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines methods to load texture images directly from the
	framebuffer.  Methods are defined for both complete and partial
	replacement of a texture image.  Because it is not possible to define
	an entire 3D texture using a 2D framebuffer image, 3D textures are
	supported only for partial replacement.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/copy_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.copy_texture import *
from OpenGL.raw.GL.EXT.copy_texture import _EXTENSION_NAME

def glInitCopyTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.index_texture

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.index_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extends the definition of texturing so that it is supported
	in color index mode.  This extension builds on the notion of
	texture images which have color index internal formats which was
	introduced in EXT_paletted_texture.
	
	This extension also introduces a new texture environment function
	ADD which is useful for combining lighting and texturing in
	color index mode.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/index_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.index_texture import *
from OpenGL.raw.GL.EXT.index_texture import _EXTENSION_NAME

def glInitIndexTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_storage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_storage',error_checker=_errors._error_checker)
GL_TEXTURE_IMMUTABLE_FORMAT=_C('GL_TEXTURE_IMMUTABLE_FORMAT',0x912F)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei)
def glTexStorage1D(target,levels,internalformat,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glTexStorage2D(target,levels,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glTexStorage3D(target,levels,internalformat,width,height,depth):pass



'''OpenGL extension NV.framebuffer_multisample_coverage

This module customises the behaviour of the 
OpenGL.raw.GL.NV.framebuffer_multisample_coverage to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the EXT_framebuffer_multisample 
	specification by providing a new function,
	RenderBufferStorageMultisampleCoverageNV, that distinguishes 
	between color samples and coverage samples.
	
	EXT_framebuffer_multisample introduced the function 
	RenderbufferStorageMultisampleEXT as a method of defining the 
	storage parameters for a multisample render buffer.  This function 
	takes a <samples> parameter.  Using rules provided by the 
	specification, the <samples> parameter is resolved to an actual 
	number of samples that is supported by the underlying hardware.  
	EXT_framebuffer_multisample does not specify whether <samples>
	refers to coverage samples or color samples.
	
	This extension adds the function 
	RenderbufferStorageMultisamplCoverageNV, which takes a 
	<coverageSamples> parameter as well as a <colorSamples> parameter.  
	These two parameters give developers more fine grained control over
	the quality of multisampled images.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/framebuffer_multisample_coverage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.framebuffer_multisample_coverage import *
from OpenGL.raw.GL.NV.framebuffer_multisample_coverage import _EXTENSION_NAME

def glInitFramebufferMultisampleCoverageNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_1_0',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glAccum(op,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glAlphaFunc(func,ref):pass
@_f
@_p.types(None,_cs.GLenum)
def glBegin(mode):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,arrays.GLubyteArray)
def glBitmap(width,height,xorig,yorig,xmove,ymove,bitmap):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glBlendFunc(sfactor,dfactor):pass
@_f
@_p.types(None,_cs.GLuint)
def glCallList(list):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p)
def glCallLists(n,type,lists):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glClear(mask):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glClearAccum(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glClearColor(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLdouble)
def glClearDepth(depth):pass
@_f
@_p.types(None,_cs.GLfloat)
def glClearIndex(c):pass
@_f
@_p.types(None,_cs.GLint)
def glClearStencil(s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glClipPlane(plane,equation):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glColor3b(red,green,blue):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glColor3bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glColor3d(red,green,blue):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glColor3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glColor3f(red,green,blue):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glColor3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glColor3i(red,green,blue):pass
@_f
@_p.types(None,arrays.GLintArray)
def glColor3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glColor3s(red,green,blue):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glColor3sv(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glColor3ub(red,green,blue):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glColor3ubv(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColor3ui(red,green,blue):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glColor3uiv(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glColor3us(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor3usv(v):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glColor4b(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glColor4bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glColor4d(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glColor4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glColor4f(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glColor4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glColor4i(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLintArray)
def glColor4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glColor4s(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glColor4sv(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glColor4ub(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glColor4ubv(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColor4ui(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glColor4uiv(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glColor4us(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor4usv(v):pass
@_f
@_p.types(None,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean)
def glColorMask(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glColorMaterial(face,mode):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum)
def glCopyPixels(x,y,width,height,type):pass
@_f
@_p.types(None,_cs.GLenum)
def glCullFace(mode):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei)
def glDeleteLists(list,range):pass
@_f
@_p.types(None,_cs.GLenum)
def glDepthFunc(func):pass
@_f
@_p.types(None,_cs.GLboolean)
def glDepthMask(flag):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glDepthRange(near,far):pass
@_f
@_p.types(None,_cs.GLenum)
def glDisable(cap):pass
@_f
@_p.types(None,_cs.GLenum)
def glDrawBuffer(buf):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glDrawPixels(width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLboolean)
def glEdgeFlag(flag):pass
@_f
@_p.types(None,arrays.GLbooleanArray)
def glEdgeFlagv(flag):pass
@_f
@_p.types(None,_cs.GLenum)
def glEnable(cap):pass
@_f
@_p.types(None,)
def glEnd():pass
@_f
@_p.types(None,)
def glEndList():pass
@_f
@_p.types(None,_cs.GLdouble)
def glEvalCoord1d(u):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glEvalCoord1dv(u):pass
@_f
@_p.types(None,_cs.GLfloat)
def glEvalCoord1f(u):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glEvalCoord1fv(u):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glEvalCoord2d(u,v):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glEvalCoord2dv(u):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glEvalCoord2f(u,v):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glEvalCoord2fv(u):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint)
def glEvalMesh1(mode,i1,i2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glEvalMesh2(mode,i1,i2,j1,j2):pass
@_f
@_p.types(None,_cs.GLint)
def glEvalPoint1(i):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glEvalPoint2(i,j):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLenum,arrays.GLfloatArray)
def glFeedbackBuffer(size,type,buffer):pass
@_f
@_p.types(None,)
def glFinish():pass
@_f
@_p.types(None,)
def glFlush():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glFogf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glFogfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glFogi(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glFogiv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum)
def glFrontFace(mode):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glFrustum(left,right,bottom,top,zNear,zFar):pass
@_f
@_p.types(_cs.GLuint,_cs.GLsizei)
def glGenLists(range):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLbooleanArray)
def glGetBooleanv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glGetClipPlane(plane,equation):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glGetDoublev(pname,data):pass
@_f
@_p.types(_cs.GLenum,)
def glGetError():pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetFloatv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glGetIntegerv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetLightiv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glGetMapdv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMapfv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMapiv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMaterialiv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetPixelMapfv(map,values):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glGetPixelMapuiv(map,values):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glGetPixelMapusv(map,values):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glGetPolygonStipple(mask):pass
@_f
@_p.types(arrays.GLubyteArray,_cs.GLenum)
def glGetString(name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glGetTexGendv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexGenfv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexGeniv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetTexImage(target,level,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLfloatArray)
def glGetTexLevelParameterfv(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLintArray)
def glGetTexLevelParameteriv(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glHint(target,mode):pass
@_f
@_p.types(None,_cs.GLuint)
def glIndexMask(mask):pass
@_f
@_p.types(None,_cs.GLdouble)
def glIndexd(c):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glIndexdv(c):pass
@_f
@_p.types(None,_cs.GLfloat)
def glIndexf(c):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glIndexfv(c):pass
@_f
@_p.types(None,_cs.GLint)
def glIndexi(c):pass
@_f
@_p.types(None,arrays.GLintArray)
def glIndexiv(c):pass
@_f
@_p.types(None,_cs.GLshort)
def glIndexs(c):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glIndexsv(c):pass
@_f
@_p.types(None,)
def glInitNames():pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glIsEnabled(cap):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsList(list):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glLightModelf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glLightModelfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glLightModeli(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glLightModeliv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glLightf(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glLighti(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glLightiv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLushort)
def glLineStipple(factor,pattern):pass
@_f
@_p.types(None,_cs.GLfloat)
def glLineWidth(width):pass
@_f
@_p.types(None,_cs.GLuint)
def glListBase(base):pass
@_f
@_p.types(None,)
def glLoadIdentity():pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glLoadMatrixd(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glLoadMatrixf(m):pass
@_f
@_p.types(None,_cs.GLuint)
def glLoadName(name):pass
@_f
@_p.types(None,_cs.GLenum)
def glLogicOp(opcode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMap1d(target,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMap1f(target,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMap2d(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMap2f(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLdouble,_cs.GLdouble)
def glMapGrid1d(un,u1,u2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glMapGrid1f(un,u1,u2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLdouble,_cs.GLdouble)
def glMapGrid2d(un,u1,u2,vn,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glMapGrid2f(un,u1,u2,vn,v1,v2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glMaterialf(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glMateriali(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glMaterialiv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum)
def glMatrixMode(mode):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glMultMatrixd(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glMultMatrixf(m):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glNewList(list,mode):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glNormal3b(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glNormal3bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glNormal3d(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glNormal3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glNormal3f(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glNormal3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glNormal3i(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLintArray)
def glNormal3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glNormal3s(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glNormal3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glOrtho(left,right,bottom,top,zNear,zFar):pass
@_f
@_p.types(None,_cs.GLfloat)
def glPassThrough(token):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLfloatArray)
def glPixelMapfv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glPixelMapuiv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLushortArray)
def glPixelMapusv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPixelStoref(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPixelStorei(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPixelTransferf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPixelTransferi(pname,param):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glPixelZoom(xfactor,yfactor):pass
@_f
@_p.types(None,_cs.GLfloat)
def glPointSize(size):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glPolygonMode(face,mode):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glPolygonStipple(mask):pass
@_f
@_p.types(None,)
def glPopAttrib():pass
@_f
@_p.types(None,)
def glPopMatrix():pass
@_f
@_p.types(None,)
def glPopName():pass
@_f
@_p.types(None,_cs.GLbitfield)
def glPushAttrib(mask):pass
@_f
@_p.types(None,)
def glPushMatrix():pass
@_f
@_p.types(None,_cs.GLuint)
def glPushName(name):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glRasterPos2d(x,y):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glRasterPos2f(x,y):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glRasterPos2i(x,y):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glRasterPos2s(x,y):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRasterPos3d(x,y,z):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRasterPos3f(x,y,z):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glRasterPos3i(x,y,z):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRasterPos3s(x,y,z):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRasterPos4d(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRasterPos4f(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glRasterPos4i(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRasterPos4s(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos4sv(v):pass
@_f
@_p.types(None,_cs.GLenum)
def glReadBuffer(src):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glReadPixels(x,y,width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRectd(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLdoubleArray,arrays.GLdoubleArray)
def glRectdv(v1,v2):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRectf(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLfloatArray,arrays.GLfloatArray)
def glRectfv(v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glRecti(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLintArray,arrays.GLintArray)
def glRectiv(v1,v2):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRects(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLshortArray,arrays.GLshortArray)
def glRectsv(v1,v2):pass
@_f
@_p.types(_cs.GLint,_cs.GLenum)
def glRenderMode(mode):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRotated(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRotatef(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glScaled(x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glScalef(x,y,z):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissor(x,y,width,height):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glSelectBuffer(size,buffer):pass
@_f
@_p.types(None,_cs.GLenum)
def glShadeModel(mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLuint)
def glStencilFunc(func,ref,mask):pass
@_f
@_p.types(None,_cs.GLuint)
def glStencilMask(mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glStencilOp(fail,zfail,zpass):pass
@_f
@_p.types(None,_cs.GLdouble)
def glTexCoord1d(s):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord1dv(v):pass
@_f
@_p.types(None,_cs.GLfloat)
def glTexCoord1f(s):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord1fv(v):pass
@_f
@_p.types(None,_cs.GLint)
def glTexCoord1i(s):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord1iv(v):pass
@_f
@_p.types(None,_cs.GLshort)
def glTexCoord1s(s):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord1sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glTexCoord2d(s,t):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glTexCoord2f(s,t):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glTexCoord2i(s,t):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glTexCoord2s(s,t):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTexCoord3d(s,t,r):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTexCoord3f(s,t,r):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glTexCoord3i(s,t,r):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glTexCoord3s(s,t,r):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTexCoord4d(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTexCoord4f(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glTexCoord4i(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glTexCoord4s(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord4sv(v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexEnvf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexEnvi(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLdouble)
def glTexGend(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glTexGendv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexGenf(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexGenfv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexGeni(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexGeniv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage1D(target,level,internalformat,width,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage2D(target,level,internalformat,width,height,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexParameterf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexParameteri(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTranslated(x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTranslatef(x,y,z):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glVertex2d(x,y):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glVertex2f(x,y):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glVertex2i(x,y):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glVertex2s(x,y):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertex3d(x,y,z):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertex3f(x,y,z):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertex3i(x,y,z):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertex3s(x,y,z):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertex4d(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertex4f(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertex4i(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertex4s(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex4sv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glViewport(x,y,width,height):pass



"""OpenGL.EGL the portable interface to GL environments"""
from OpenGL.raw.GLES2._types import *
from OpenGL.GLES2.VERSION.GLES2_2_0 import *

from OpenGL.GLES2 import vboimplementation as _gles2_implementation



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_3'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_3',error_checker=_errors._error_checker)
EGL_CONFORMANT=_C('EGL_CONFORMANT',0x3042)
EGL_CONTEXT_CLIENT_VERSION=_C('EGL_CONTEXT_CLIENT_VERSION',0x3098)
EGL_MATCH_NATIVE_PIXMAP=_C('EGL_MATCH_NATIVE_PIXMAP',0x3041)
EGL_OPENGL_ES2_BIT=_C('EGL_OPENGL_ES2_BIT',0x0004)
EGL_VG_ALPHA_FORMAT=_C('EGL_VG_ALPHA_FORMAT',0x3088)
EGL_VG_ALPHA_FORMAT_NONPRE=_C('EGL_VG_ALPHA_FORMAT_NONPRE',0x308B)
EGL_VG_ALPHA_FORMAT_PRE=_C('EGL_VG_ALPHA_FORMAT_PRE',0x308C)
EGL_VG_ALPHA_FORMAT_PRE_BIT=_C('EGL_VG_ALPHA_FORMAT_PRE_BIT',0x0040)
EGL_VG_COLORSPACE=_C('EGL_VG_COLORSPACE',0x3087)
EGL_VG_COLORSPACE_LINEAR=_C('EGL_VG_COLORSPACE_LINEAR',0x308A)
EGL_VG_COLORSPACE_LINEAR_BIT=_C('EGL_VG_COLORSPACE_LINEAR_BIT',0x0020)
EGL_VG_COLORSPACE_sRGB=_C('EGL_VG_COLORSPACE_sRGB',0x3089)

